; Slotest - little exercises for the interrupt driver
; Simon N Goodwin November 2023, April 2024

        ORG  49000              ; Fully relocatable

; 49000 Clobber border colour with data value 0..7
border  LD   A,E
        OUT  (254),A
        RET

; 49004 PSG noise wobbler
wobbler LD   BC,65533           ; Select AY register
        LD   A,6
        OUT  (C),A
        LD   A,(DE)             ; Get first data byte
        INC  A
        LD   (DE),A
        LD   BC,49149
        SRL  A                  ; Map 0..255 to 0..31
        SRL  A
        SRL  A
        OUT  (C),A
        RET

; 49026 Key translator, suits PEEK not INKEY$
rekey   LD   HL,23560
        LD   A,(HL)
        CP   201                ; Sym W <>
        RET  NZ
        LD   (HL),127           ; 
        RET

; 49036 Slide ULA layers annoyingly with wobbler
scrolly LD   BC,9275            ; REG select port
        LD   A,38               ; ULA pan register
        OUT  (C),A              ; Select register
        LD   A,(DE)             ; Data byte
        BIT  7,A
        JR   Z,move
        NEG                     ; Flip direction

move    INC  B                  ; Data port 9531
        OUT  (C),A              ; Pan screen
        RET

; 49054, Delay; enter at 49055 to stop early at 0
delay   DEC  DE
delay0  LD   A,D
        OR   E
        JR   NZ,delay
        RET

; 49060, Blink; position-independent data follows
blink   LD   BC,count-blink     ; Offset to data
        ADD  HL,BC              ; Point at data
        DEC  (HL)               ; Count down
        RET  NZ

        INC  HL
        LD   A,(HL)             ; Read rate
        DEC  HL
        LD   (HL),A             ; Reset count to rate
        INC  HL
        INC  HL
        LD   A,(HL)             ; Read old port state
        XOR  1                  ; Toggle output bit
        NEXTREG 11,A
        LD   (HL),A             ; Update port state
        RET

; blink+20, default 49080..49082: Blink state
count   DB   0                  ; Frames till next blink
rate    DB   0                  ; Frames between blinks
oldOut  DB   0                  ; Last output to port

last                            ; Stay below 49152!
length  EQU  last-border

        SAVE "SLOTEST",49000,length

